@@ -2,8 +2,10 @@
 
 mod combinatorial;
 mod gamma;
+mod interpolate;
 mod statistical;
 
 pub use self::combinatorial::*;
 pub use self::gamma::*;
+pub use self::interpolate::*;
 pub use self::statistical::*;
