@@ -1,3 +1,5 @@
+use serde::{Deserialize, Serialize};
+use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Sub, SubAssign};
 use std::{
     fmt::{Display, Formatter, Result},
     mem::swap,
@@ -5,8 +7,6 @@ use std::{
     panic,
 };
 
-use std::ops::{Add, AddAssign, Div, DivAssign, Mul, MulAssign, Sub, SubAssign};
-
 use crate::prelude::{transpose, Dot};
 
 use super::super::utils::{dot, ipiv_parity};
@@ -14,7 +14,7 @@ use super::vops::*;
 use super::{broadcast_add, broadcast_div, broadcast_mul, broadcast_sub, Vector};
 
 /// Matrix struct.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Matrix {
     data: Vector,
     pub nrows: usize,
